@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import locale
 import gc
@@ -52,7 +52,6 @@ class MainWindow(object):
         sys.path.append(os.path.join(self.path, "plugins"))
 
         self.de = de
-        self.icon = "/usr/lib/linuxmint/mintMenu/visualisation-logo.png"
 
         self.toggle = toggleButton
         builder = Gtk.Builder()
@@ -132,7 +131,7 @@ class MainWindow(object):
                 try:
                     X = __import__(plugin)
                     # If no parameter passed to plugin it is autonomous
-                    if X.pluginclass.__init__.func_code.co_argcount == 1:
+                    if X.pluginclass.__init__.__code__.co_argcount == 1:
                         MyPlugin = X.pluginclass()
                     else:
                         # pass mintMenu and togglebutton instance so that the plugin can use it
@@ -330,6 +329,7 @@ class MenuWin(object):
         self.detect_desktop_environment()
         self.settings = Gio.Settings.new("com.linuxmint.mintmenu")
         self.icon_theme = Gtk.IconTheme.get_default()
+        self.button_icon = Gtk.Image()
         self.loadSettings()
 
         self.createPanelButton()
@@ -358,9 +358,6 @@ class MenuWin(object):
         self.mainwin.window.set_name("mintmenu") # Name used in Gtk RC files
         self.applyTheme()
 
-        if self.mainwin.icon:
-            Gtk.Window.set_default_icon_name(self.mainwin.icon)
-
         try:
             self.keybinder = keybinding.GlobalKeyBinding()
             if self.hotkeyText != "":
@@ -424,19 +421,18 @@ class MenuWin(object):
         self.set_applet_icon()
 
     def set_applet_icon(self, saturate=False):
-        if saturate:
-            self.button_icon.set_from_pixbuf(self.saturated_pixbuf)
-        else:
-            self.button_icon.set_from_pixbuf(self.pixbuf)
+        if not self.symbolic:
+            if saturate:
+                self.button_icon.set_from_surface(self.saturated_surface)
+            else:
+                self.button_icon.set_from_surface(self.surface)
 
     def createPanelButton(self):
-        self.button_icon = Gtk.Image()
         self.set_applet_icon()
         self.systemlabel = Gtk.Label(label= "%s " % self.buttonText)
         if os.path.isfile("/etc/linuxmint/info"):
             with open("/etc/linuxmint/info") as info:
                 for line in info:
-                    line = line.decode("utf-8")
                     if line.startswith("DESCRIPTION="):
                         tooltip = line.split("=",1)[1].strip('"\n')
                         self.systemlabel.set_tooltip_text(tooltip)
@@ -477,16 +473,26 @@ class MenuWin(object):
         applet_icon = self.settings.get_string("applet-icon")
         if not (os.path.exists(applet_icon) or self.icon_theme.has_icon(applet_icon)):
             self.settings.reset("applet-icon")
-        applet_icon = self.settings.get_string("applet-icon")
+        self.scale = self.button_icon.get_scale_factor()
+        self.symbolic = False
+        self.pixbuf = None
         if "/" in applet_icon:
             if applet_icon.endswith(".svg"):
-                self.pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(applet_icon, -1, 22)
+                self.pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(applet_icon, -1, 22 * self.scale)
             else:
                 self.pixbuf = GdkPixbuf.Pixbuf.new_from_file(applet_icon)
         else:
-            self.pixbuf = self.icon_theme.load_icon(applet_icon, 22, 0)
-        self.saturated_pixbuf = self.pixbuf.copy()
-        GdkPixbuf.Pixbuf.saturate_and_pixelate(self.saturated_pixbuf, self.saturated_pixbuf, 1.5, False)
+            if applet_icon.endswith("symbolic"):
+                self.button_icon.set_from_icon_name(applet_icon, Gtk.IconSize.DIALOG)
+                self.button_icon.set_pixel_size(22)
+                self.symbolic = True
+            else:
+                self.pixbuf = self.icon_theme.load_icon(applet_icon, 22 * self.scale, 0)
+        if self.pixbuf is not None:
+            self.surface = Gdk.cairo_surface_create_from_pixbuf(self.pixbuf, self.scale)
+            self.saturated_pixbuf = self.pixbuf.copy()
+            GdkPixbuf.Pixbuf.saturate_and_pixelate(self.saturated_pixbuf, self.saturated_pixbuf, 1.5, False)
+            self.saturated_surface = Gdk.cairo_surface_create_from_pixbuf(self.saturated_pixbuf, self.scale)
         self.buttonIcon =  self.settings.get_string("applet-icon")
         self.iconSize = self.settings.get_int("applet-icon-size")
 
@@ -539,7 +545,6 @@ class MenuWin(object):
 
     def updateButton(self):
         self.systemlabel.set_text(self.buttonText)
-        self.button_icon.clear()
         self.set_applet_icon()
         self.sizeButton()
 
@@ -576,13 +581,9 @@ class MenuWin(object):
 
     def showAboutDialog(self, action, userdata = None):
         about = Gtk.AboutDialog()
-        about.set_name("mintMenu")
+        about.set_program_name("mintMenu")
         about.set_version("__DEB_VERSION__")
-        try:
-            gpl = open('/usr/share/common-licenses/GPL','r').read()
-            about.set_license(gpl)
-        except Exception as e:
-            print(e)
+        about.set_license_type(Gtk.License.GPL_3_0)
         about.set_comments(_("Advanced MATE Menu"))
         # about.set_authors(["Clement Lefebvre <clem@linuxmint.com>", "Lars-Peter Clausen <lars@laprican.de>"])
         about.set_translator_credits(("translator-credits"))
@@ -595,10 +596,10 @@ class MenuWin(object):
         Execute("/usr/lib/linuxmint/mintMenu/preferences.py")
 
     def showMenuEditor(self, action, userdata = None):
-        if os.path.exists("/usr/bin/menulibre"):
-            Execute("menulibre")
-        elif os.path.exists("/usr/bin/mozo"):
+        if os.path.exists("/usr/bin/mozo"):
             Execute("mozo")
+        elif os.path.exists("/usr/bin/menulibre"):
+            Execute("menulibre")
 
     def showMenu(self, widget=None, event=None):
         if event == None or event.button == 1:
