@@ -1,4 +1,4 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import cgi
 import filecmp
@@ -7,12 +7,13 @@ import locale
 import os
 import subprocess
 import threading
-import urllib
+import urllib.request, urllib.parse, urllib.error
 
 import gi
 gi.require_version("Gtk", "3.0")
 gi.require_version("MateMenu", "2.0")
-from gi.repository import Gtk, Gdk, GdkPixbuf, Gio, GLib, MateMenu
+gi.require_version("XApp", "1.0")
+from gi.repository import Gtk, Gdk, GdkPixbuf, Gio, GLib, MateMenu, XApp
 
 import plugins.recentHelper as RecentHelper
 from plugins.easybuttons import (ApplicationLauncher, CategoryButton,
@@ -173,11 +174,11 @@ class pluginclass(object):
     toButton = (Gtk.TargetEntry.new("text/uri-list", 0, TARGET_TYPE_TEXT),
                 Gtk.TargetEntry.new("text/uri-list", 0, TARGET_TYPE_TEXT))
     TARGET_TYPE_FAV = 81
-    toFav = (Gtk.TargetEntry.new("FAVORITES", Gtk.TargetFlags.SAME_APP, 81),
+    toFav = (Gtk.TargetEntry.new("text/plain", Gtk.TargetFlags.SAME_APP, 81),
              Gtk.TargetEntry.new("text/plain", 0, 100),
              Gtk.TargetEntry.new("text/uri-list", 0, 101))
-    fromFav = (Gtk.TargetEntry.new("FAVORITES", Gtk.TargetFlags.SAME_APP, 81),
-               Gtk.TargetEntry.new("FAVORITES", Gtk.TargetFlags.SAME_APP, 81))
+    fromFav = (Gtk.TargetEntry.new("text/plain", Gtk.TargetFlags.SAME_APP, 81),
+               Gtk.TargetEntry.new("text/plain", Gtk.TargetFlags.SAME_APP, 81))
 
     #@print_timing
     def __init__(self, mintMenuWin, toggleButton, de):
@@ -245,6 +246,9 @@ class pluginclass(object):
         try:
             # GSettings stuff
             self.settings = Gio.Settings("com.linuxmint.mintmenu.plugins.applications")
+
+            self.migrate_favorites()
+
             self.GetGSettingsEntries()
             self.settings.connect("changed::icon-size", self.changeIconSize)
             self.settings.connect("changed::favicon-size", self.changeFavIconSize)
@@ -264,6 +268,7 @@ class pluginclass(object):
             self.settings.connect("changed::enable-internet-search", self.GetGSettingsEntries)
             self.settings.connect("changed::search-command", self.GetGSettingsEntries)
             self.settings.connect("changed::default-tab", self.GetGSettingsEntries)
+            self.settings.connect("changed::favorite-apps-list", self.favoriteAppsChanged)
         except Exception as e:
             print(e)
 
@@ -519,16 +524,6 @@ class pluginclass(object):
     def RebuildPlugin(self):
         self.content_holder.set_size_request(self.width, self.height)
 
-    def checkMintMenuFolder(self):
-        if os.path.exists(os.path.join(os.path.expanduser("~"), ".linuxmint", "mintMenu", "applications")):
-            return True
-        try:
-            os.makedirs(os.path.join(os.path.expanduser("~"), ".linuxmint", "mintMenu", "applications"))
-            return True
-        except:
-            pass
-        return False
-
     def onShowMenu(self):
         if self.favorites:
             if self.defaultTab == -1:
@@ -997,17 +992,17 @@ class pluginclass(object):
         self.focusSearchEntry(clear = False)
 
     def search_ddg(self, widget):
-        text = urllib.quote_plus(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote_plus(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://duckduckgo.com/?q=%s" % text])
         self.mintMenuWin.hide()
 
     def search_google(self, widget):
-        text = urllib.quote_plus(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote_plus(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://www.google.com/search?q=%s" % text])
         self.mintMenuWin.hide()
 
     def search_wikipedia(self, widget):
-        text = urllib.quote_plus(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote_plus(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://en.wikipedia.org/wiki/Special:Search?search=%s" % text])
         self.mintMenuWin.hide()
 
@@ -1017,27 +1012,27 @@ class pluginclass(object):
         self.mintMenuWin.hide()
 
     def search_mint_tutorials(self, widget):
-        text = urllib.quote(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://community.linuxmint.com/index.php/tutorial/search/0/%s" % text])
         self.mintMenuWin.hide()
 
     def search_mint_ideas(self, widget):
-        text = urllib.quote(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://community.linuxmint.com/index.php/idea/search/0/%s" % text])
         self.mintMenuWin.hide()
 
     def search_mint_users(self, widget):
-        text = urllib.quote(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://community.linuxmint.com/index.php/user/search/0/%s" % text])
         self.mintMenuWin.hide()
 
     def search_mint_hardware(self, widget):
-        text = urllib.quote(self.searchEntry.get_text().strip())
+        text = urllib.parse.quote(self.searchEntry.get_text().strip())
         subprocess.Popen(["xdg-open", "https://community.linuxmint.com/index.php/hardware/search/0/%s" % text])
         self.mintMenuWin.hide()
 
     def search_mint_software(self, widget):
-        text = urllib.quote(self.searchEntry.get_text())
+        text = urllib.parse.quote(self.searchEntry.get_text())
         subprocess.Popen(["xdg-open", "https://community.linuxmint.com/index.php/software/search/0/%s" % text])
         self.mintMenuWin.hide()
 
@@ -1245,26 +1240,44 @@ class pluginclass(object):
 
         return None
 
+    def migrate_favorites(self):
+        if self.settings.get_strv("favorite-apps-list") != []:
+            return
+
+        default_path = os.path.join("/usr/lib/linuxmint/mintMenu/applications.list")
+        path = os.path.join(home, ".linuxmint/mintMenu/applications.list")
+
+        if os.path.isdir(path):
+            # dir created by a bug in mint 19.2 beta
+            os.system("rm -rf %s" % path)
+            return
+
+        if not os.path.exists(path):
+            path = default_path
+
+        with open(path) as f:
+            self.settings.set_strv("favorite-apps-list", f.readlines())
+
+        try:
+            os.replace(path, path + ".deprecated_uses_dconf_now")
+        except:
+            # This will fail if it was the default path, ignore it.
+            pass
+
+    def favoriteAppsChanged(self, setting, key):
+        self.buildFavorites()
+
     def buildFavorites(self):
         try:
-            path = os.path.join(home, ".linuxmint/mintMenu/applications.list")
-            if os.path.isdir(path):
-                # dir created by a bug in mint 19.2 beta
-                os.system("rm -rf %s" % path)
-            if not os.path.exists(path):
-                os.system("mkdir -p ~/.linuxmint/mintMenu")
-                os.system("cp /usr/lib/linuxmint/mintMenu/applications.list " + path)
-
-            applicationsList = open(path).readlines()
-
-            self.favorites =  []
+            faves = self.settings.get_strv("favorite-apps-list")
 
             for child in self.favoritesBox:
                 child.destroy()
 
             position = 0
+            self.favorites = []
 
-            for app in applicationsList:
+            for app in faves:
                 try:
                     app = app.strip()
 
@@ -1296,7 +1309,6 @@ class pluginclass(object):
                     print("Can't add favorite: %s" % app)
                     print (e)
 
-            self.favoritesSave()
         except Exception as e:
             print(e)
 
@@ -1382,20 +1394,15 @@ class pluginclass(object):
                 self.favoritesRemove(fav.position)
 
     def favoritesSave(self):
-        try:
-            self.checkMintMenuFolder()
-            with open(os.path.join(home, ".linuxmint/mintMenu/applications.list") , "w") as appListFile:
-                for favorite in self.favorites:
-                    if favorite.type == "location":
-                        appListFile.write("location:" + favorite.desktopFile + "\n")
-                    else:
-                        appListFile.write(favorite.type + "\n")
-        except Exception as e:
-            msgDlg = Gtk.MessageDialog(None, Gtk.DialogFlags.MODAL, Gtk.MessageType.ERROR, Gtk.ButtonsType.OK,
-                _("Couldn't save favorites. Check if you have write access to ~/.linuxmint/mintMenu") +
-                "\n(" + e.__str__() + ")")
-            msgDlg.run()
-            msgDlg.destroy()
+        new_faves = []
+
+        for favorite in self.favorites:
+            if favorite.type == "location":
+                new_faves.append("location:" + favorite.desktopFile)
+            else:
+                new_faves.append(favorite.type)
+
+        self.settings.set_strv("favorite-apps-list", new_faves)
 
     def isLocationInFavorites(self, location):
         for fav in self.favorites:
@@ -1406,12 +1413,11 @@ class pluginclass(object):
     def on_drag_data_get(self, widget, context, selection, info, time):
         if info == self.TARGET_TYPE_FAV:
             self.drag_origin = widget.position
-            # FIXME: This fails in python3:
-            selection.set(selection.get_target(), 8, str(widget.position))
+            selection.set_text(str(widget.position), -1)
 
     def on_drag_data_received(self, widget, context, x, y, selection, info, time):
         if info == self.TARGET_TYPE_FAV:
-            self.favoritesReorder(int(selection.get_data()), widget.position)
+            self.favoritesReorder(int(selection.get_data().decode()), widget.position)
 
     # def on_icon_theme_changed(self, theme):
     #     print("on_icon_theme_changed")
