@@ -1,7 +1,8 @@
-#!/usr/bin/python2
+#!/usr/bin/python3
 
 import os.path
 import shutil
+import unidecode
 
 import xdg.DesktopEntry
 import xdg.Menu
@@ -128,7 +129,7 @@ class easyButton(Gtk.Button):
 
         if labels:
             for label in labels:
-                if isinstance(label, basestring):
+                if isinstance(label, str):
                     self.addLabel(label)
                 elif isinstance(label, list):
                     self.addLabel(label[0], label[1])
@@ -258,10 +259,10 @@ class ApplicationLauncher(easyButton):
 
     def loadDesktopEntry(self, desktopItem):
         try:
-            self.appName = self.strip_accents(desktopItem.getName())
-            self.appGenericName = self.strip_accents(desktopItem.getGenericName())
-            self.appComment = self.strip_accents(desktopItem.getComment())
-            self.appExec = self.strip_accents(desktopItem.getExec().replace('\\\\', '\\'))
+            self.appName = desktopItem.getName()
+            self.appGenericName = desktopItem.getGenericName()
+            self.appComment = desktopItem.getComment()
+            self.appExec = desktopItem.getExec().replace('\\\\', '\\')
             self.appIconName = desktopItem.getIcon()
             self.appCategories = desktopItem.getCategories()
             self.appMateDocPath = desktopItem.get("X-MATE-DocPath") or ""
@@ -303,24 +304,22 @@ class ApplicationLauncher(easyButton):
         self.addLabel(self.appName)
 
     def filterText(self, text):
-        keywords = text.lower().split()
-        appName = self.appName.lower()
-        appGenericName = self.appGenericName.lower()
-        appComment = self.appComment.lower()
-        appExec = self.appExec.lower()
+        keywords = self.strip_case_and_accents(text).split()
+        appName = self.strip_case_and_accents(self.appName)
+        appGenericName = self.strip_case_and_accents(self.appGenericName)
+        appComment = self.strip_case_and_accents(self.appComment)
+        appExec = self.strip_case_and_accents(self.appExec)
         for keyword in keywords:
-            keyw = self.strip_accents(keyword)
-            if keyw != "" and appName.find(keyw) == -1 and appGenericName.find(keyw) == -1 and appComment.find(keyw) == -1 and appExec.find(keyw) == -1:
+            if keyword != "" and appName.find(keyword) == -1 and appGenericName.find(keyword) == -1 and appComment.find(keyword) == -1 and appExec.find(keyword) == -1:
                 self.hide()
                 return False
         self.show()
         return True
 
-    def strip_accents(self, string):
-        value = string
-        if isinstance(string, unicode):
+    def strip_case_and_accents(self, string):
+        if isinstance(string, str):
             try:
-                value = string.encode('UTF8', 'ignore')
+                value = unidecode.unidecode(string.lower())
             except:
                 pass
         return value
@@ -385,13 +384,6 @@ class ApplicationLauncher(easyButton):
         if os.path.exists(self.startupFilePath):
             os.remove(self.startupFilePath)
 
-    def addToFavourites(self):
-        favouritesDir = os.path.join(os.path.expanduser("~"), ".linuxmint/mintMenu/applications")
-        if not os.path.exists(favouritesDir):
-            os.makedirs(favouritesDir)
-
-        shutil.copyfile(self.desktopFile, self.favouritesFilePath)
-
     def removeFromFavourites(self):
         if os.path.exists(self.favouritesFilePath):
             os.remove(self.favouritesFilePath)
